@@ -1,6 +1,9 @@
 def add(a,b):
     return a+b
-
+import pandas as pd 
+import re ,spacy
+nlp = spacy.load('en_core_web_lg')
+nlp.add_pipe('coreferee')
 
 #1 count frequence of list
 def countFreq(my_list,extra_name=""):
